| Home | Libraries | People | FAQ | More

### remove_volatile

    template <class T>
    struct remove_volatile
    {
       typedef see-below type;
    };

type: The same type as `T`, but with any top level volatile-qualifier removed.

C++ Standard Reference: 3.9.3.

Compiler Compatibility: If the compiler does not support partial specialization of class-templates then this template will compile, but the member `type` will always be the same as type `T` except where compiler workarounds have been applied.

Header: `#include <boost/type_traits/remove_volatile.hpp>` or `#include <boost/type_traits.hpp>`

Table 1.31. Examples

Expression | Result Type
--- | ---
`remove_volatile<int>::type` | `int`
`remove_volatile<int volatile>::type` | `int`
`remove_volatile<int const volatile>::type` | `int const`
`remove_volatile<int volatile&>::type` | `int const&`
`remove_volatile<int volatile*>::type` | `int const*`